@@ -5,3 +5,8 @@ from .memberipremoverequest import MemberIPRemoveRequest
 from .memberipreplacerequest import MemberIPReplaceRequest
 from .pendingtransferrequest import PendingTransferRequest
 from .verifytransferrequest import VerifyTransferRequest
+
+__all__ = [
+    'DepositsRequest', 'FullySignedTransferRequest', 'MemberIPAddRequest', 'MemberIPRemoveRequest', 'MemberIPReplaceRequest',
+    'PendingTransferRequest', 'VerifyTransferRequest'
+]
